import "./styles.css";
import { jsonData as jsonData1 } from "./mockData";

import { sheetStyles, editModeStyles, defaults } from "./styles.js";
// initSpread(spread);

window.onload = async function () {
  const fontFile = new FontFace("Poppins", "url(PoppinsRegular.ttf)");
  
  document.fonts.add(fontFile);

  fontFile.load().then(function(){
    console.log("Font Loaded Successfully")
    var spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"));
    initSpread(spread);
  }, (err) => {
    console.log('error');
    console.log(err);
  })
}


function initSpread(spread) {
  window["spread"] = spread;
  const workSheetResponse = jsonData1.results;

  workSheetResponse.namedStyles = [...sheetStyles, ...editModeStyles];
  workSheetResponse.sheets.Sheet1.defaults = defaults;
  initSpreadData(spread, workSheetResponse);
  console.log(spread);
  spread.invalidateLayout();
}

function applyCellStyle(sheet, row, col) {
  if (!sheet) return;

  sheet.getCell(row, col).font("bold 24px Poppins");
}

let _oldFn = GC.Spread.Sheets.CellTypes.Base.prototype.getAutoFitWidth;
GC.Spread.Sheets.CellTypes.Base.prototype.getAutoFitWidth = function () {
  let minWidth = 100;
  let width = _oldFn.apply(this, arguments);
  return Math.max(minWidth, width);
};

function initSpreadData(spread, jsonData1) {
  spread.fromJSON(jsonData1);
  spread
    .commandManager()
    .setShortcutKey("", GC.Spread.Commands.Key.z, true, false, false, false);
  spread.options.allowContextMenu = false;
  spread.options.tabStripVisible = false;
  spread.options.showHorizontalScrollbar = true;
  spread.options.showVerticalScrollbar = true;
  spread.options.scrollbarMaxAlign = true;
  spread.options.scrollByPixel = true;
  spread.options.allowUserDragDrop = false;
  spread.options.allowUserDragFill = false;
  let sheet = spread?.getActiveSheet();
  sheet.suspendPaint();
  sheet.zoom(1.1);
  sheet.defaults.rowHeight = 50;
  //sheet.options.isProtected = true;
  sheet.options.protectionOptions.allowEditObjects = true;
  sheet.options.protectionOptions.allowResizeColumns = true;
  var rowCount = sheet.getRowCount();
  var colCounts = sheet.getColumnCount();
  let gFormatter = {};
  let gFormatterMultiEntry = {};
  let styleFormatter =
    "_(## ## ## ## ## ## ## ## ###.00000_);_(-## ## ## ## ## ## ## ## ###.00000_);0.00000;[Red]_(@_)";
  gFormatter = new GC.Spread.Formatter.GeneralFormatter(
    styleFormatter,
    "en-us"
  );

  const CustomFormatType = new GC.Spread.Formatter.GeneralFormatter("", "");

  const CustomFormatTypeForMultiEntryMO = new GC.Spread.Formatter.GeneralFormatter(
    "",
    ""
  );

  const formatterProducer = (formatter) => {
    return function (obj, formattedData) {
      if (typeof obj === "number") {
        return formatNumber(obj, formattedData, formatter);
      } else if (typeof obj === "string") {
        if (Number.isFinite(Number(obj))) {
          return formatNumber(parseFloat(obj), formattedData, formatter);
        }
      }
      return obj ? obj.toString() : "";
    };
  };

  CustomFormatType.format = formatterProducer(gFormatter);
  CustomFormatTypeForMultiEntryMO.format = formatterProducer(
    gFormatterMultiEntry
  );

  const formatNumber = (value, formattedData, formatter) => {
    let newFormattedValue = formatter.format(value, formattedData);

    let content = [];
    let pushToContent = false;
    formattedData.content.forEach((item) => {
      switch (item.type) {
        case "decimalSeparator":
          item.value = ".";
          content.push(item);
          break;

        case "groupSeparator":
          item.value = ",";
          content.push(item);
          break;

        case "text":
          if (item.value === " ") {
            if (pushToContent) {
              item.value = ",";
              content.push(item);
            }
          } else {
            content.push(item);
          }
          break;

        case "number":
          content.push(item);
          pushToContent = true;
          break;

        default:
          content.push(item);
      }
    });
    formattedData.content = content;
    // return value;
    return newFormattedValue;
  };

  for (let i = 1; i < rowCount; i++) {
    for (let j = 0; j < colCounts; j++) {
      // var cell = sheet.getCell(i, j);
      applyCellStyle(sheet, i, j);
    }
  }

  sheet.resumePaint();
  //   setSpread(spread);
}
// eslint-disable-next-line react-hooks/exhaustive-deps
